@@ -124,8 +124,8 @@ struct aco_type {
 	const char *name;       /*!< The name of this type (must match XML documentation) */
 	const char *category;   /*!< A regular expression for matching categories to be allowed or denied */
 	const char *matchfield; /*!< An option name to match for this type (i.e. a 'type'-like column) */
-	const char *matchvalue; /*!< The value of the option to require for matching (i.e. 'peer' for type= in sip.conf) */
-	aco_matchvalue_func matchfunc;       /*!< A function for determining whether the option value matches (i.e. hassip= requires ast_true()) */
+	const char *matchvalue; /*!< The value of the option to require for matching (i.e. 'peer') */
+	aco_matchvalue_func matchfunc;       /*!< A function for determining whether the option value matches */
 	enum aco_category_op category_match; /*!< Whether the following category regex is a whitelist or blacklist */
 	size_t item_offset;                  /*!< The offset in the config snapshot for the global config or item config container */
 	unsigned int hidden;  /*!< Type is for internal purposes only and it and all options should not be visible to users */
@@ -167,12 +167,12 @@ struct aco_file {
 };
 
 struct aco_info {
-	const char *module;			/*!< The name of the module whose config is being processed */
-	unsigned int hidden:1;			/*!< If enabled, this config item is hidden from users */
-	aco_pre_apply_config pre_apply_config;	/*!< A callback called after processing, but before changes are applied */
+	const char *module; /*!< The name of the module whose config is being processed */
+	unsigned int hidden:1;                /*!< If enabled, this config item is hidden from users */
+	aco_pre_apply_config pre_apply_config; /*!< A callback called after processing, but before changes are applied */
 	aco_post_apply_config post_apply_config;/*!< A callback called after changes are applied */
-	aco_snapshot_alloc snapshot_alloc;	/*!< Allocate an object to hold all global configs and item containers */
-	struct ao2_global_obj *global_obj;	/*!< The global object array that holds the user-defined config object */
+	aco_snapshot_alloc snapshot_alloc;     /*!< Allocate an object to hold all global configs and item containers */
+	struct ao2_global_obj *global_obj;     /*!< The global object array that holds the user-defined config object */
 	struct aco_info_internal *internal;
 	struct aco_file *files[];    /*!< An array of aco_files to process */
 };
