@@ -114,7 +114,7 @@ struct ast_channel_snapshot_base {
 	);
 	struct timeval creationtime; /*!< The time of channel creation */
 	int tech_properties;         /*!< Properties of the channel's technology */
-	AST_STRING_FIELD_EXTENDED(protocol_id); /*!< Channel driver protocol id (i.e. Call-ID for chan_sip/chan_pjsip) */
+	AST_STRING_FIELD_EXTENDED(protocol_id); /*!< Channel driver protocol id (i.e. Call-ID for chan_pjsip) */
 };
 
 /*!
@@ -132,9 +132,7 @@ struct ast_channel_snapshot_peer {
  */
 struct ast_channel_snapshot_hangup {
 	int cause;      /*!< Why is the channel hanged up. See causes.h */
-	char *source;   /*!< Who is responsible for hanging up this channel */
-	int tech_cause; /*!< Technology-specific hangup cause */
-	char buffer[0]; /*!< \private Buffer to store source in */
+	char source[0]; /*!< Who is responsible for hanging up this channel */
 };
 
 /*!
@@ -588,22 +586,6 @@ struct stasis_message_type *ast_channel_fax_type(void);
  */
 struct stasis_message_type *ast_channel_hangup_handler_type(void);
 
-/*!
- * \since 12
- * \brief Message type for starting monitor on a channel
- *
- * \return A stasis message type
- */
-struct stasis_message_type *ast_channel_monitor_start_type(void);
-
-/*!
- * \since 12
- * \brief Message type for stopping monitor on a channel
- *
- * \return A stasis message type
- */
-struct stasis_message_type *ast_channel_monitor_stop_type(void);
-
 /*!
  * \since 18
  * \brief Message type for starting mixmonitor on a channel
@@ -676,6 +658,14 @@ struct stasis_message_type *ast_channel_talking_start(void);
  */
 struct stasis_message_type *ast_channel_talking_stop(void);
 
+/*!
+ * \since 22.0.0
+ * \brief Message type for a channel tone detection
+ *
+ * \return A stasis message type
+ */
+struct stasis_message_type *ast_channel_tone_detect(void);
+
 /*
  * \since 23
  * \brief Message type for a attended or blind transfer request
